package sunmi.paylib;

import android.annotation.SuppressLint;
import android.app.Dialog;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.os.Binder;
import android.os.IBinder;
import android.os.IInterface;
import android.util.Log;
import android.view.Window;
import android.widget.Toast;

import com.sunmi.pay.hardware.aidl.DeviceProvide;
import com.sunmi.pay.hardware.aidl.emv.EMVOpt;
import com.sunmi.pay.hardware.aidl.pinpad.PinPadOpt;
import com.sunmi.pay.hardware.aidl.print.PrinterOpt;
import com.sunmi.pay.hardware.aidl.readcard.ReadCardOpt;
import com.sunmi.pay.hardware.aidl.security.SecurityOpt;
import com.sunmi.pay.hardware.aidl.system.BasicOpt;
import com.sunmi.pay.hardware.aidl.tax.TaxOpt;
import com.sunmi.pay.hardware.aidlv2.emv.EMVOptV2;
import com.sunmi.pay.hardware.aidlv2.etc.ETCOptV2;
import com.sunmi.pay.hardware.aidlv2.pinpad.PinPadOptV2;
import com.sunmi.pay.hardware.aidlv2.print.PrinterOptV2;
import com.sunmi.pay.hardware.aidlv2.readcard.ReadCardOptV2;
import com.sunmi.pay.hardware.aidlv2.security.SecurityOptV2;
import com.sunmi.pay.hardware.aidlv2.system.BasicOptV2;
import com.sunmi.pay.hardware.aidlv2.tax.TaxOptV2;

import java.util.List;

/** 连接SDK ADIL服务 */
public class SunmiPayKernel {
    private static final String TAG = "SunmiPayKernel";
    /** 基础操作模块 */
    public BasicOpt mBasicOpt;
    /** 读卡模块 */
    public ReadCardOpt mReadCardOpt;
    /** PinPad操作模块 */
    public PinPadOpt mPinPadOpt;
    /** EMV操作模块 */
    public EMVOpt mEMVOpt;
    /** 安全加密模块 */
    public SecurityOpt mSecurityOpt;
    /** 打印模块 */
    public PrinterOpt mPrinterOpt;
    /** 税控模块 */
    public TaxOpt mTaxOpt;

    /** 基础操作模块(V2版本) */
    public BasicOptV2 mBasicOptV2;
    /** 读卡模块(V2版本) */
    public ReadCardOptV2 mReadCardOptV2;
    /** PinPad操作模块(V2版本) */
    public PinPadOptV2 mPinPadOptV2;
    /** EMV操作模块(V2版本) */
    public EMVOptV2 mEMVOptV2;
    /** 安全加密模块(V2版本) */
    public SecurityOptV2 mSecurityOptV2;
    /** 打印模块(V2版本) */
    public PrinterOptV2 mPrinterOptV2;
    /** 税控模块(V2版本) */
    public TaxOptV2 mTaxOptV2;
    /** ETC模块(V2版本) */
    public ETCOptV2 mETCOptV2;
    /** SDK连接回调 */
    private ConnCallback mConnCallback;
    /** SDK连接回调(V2版本) */
    private ConnectCallback mConnCallbackV2;

    /** 支付service是否已经绑定 */
    private boolean isBind = false;
    private Context appContext;
    @SuppressLint("StaticFieldLeak")
    private static SunmiPayKernel instance = new SunmiPayKernel();

    private SunmiPayKernel() {
    }

    public static SunmiPayKernel getInstance() {
        return instance;
    }

    /** Get ApplicationContext */
    public Context getAppContext() {
        return appContext;
    }

    /** Set ApplicationContext */
    public void setAppContext(Context appContext) {
        this.appContext = appContext;
    }

    /** Get this PayLib version */
    public String getPayLibVersion() {
        return "1.4.44T01";
    }

    /**
     * Get pay sdk version which matched this PayLib,
     * for backward compatibility, the installed sdk version
     * should great or equal this method returned value
     */
    public String getMatchedPaySDKVersion() {
        return "v3.3.93";
    }

    /**
     * 绑定支付SDK
     *
     * @param context      Context对象
     * @param connCallback 绑定操作回调对象
     */
    @Deprecated
    public void connectPayService(Context context, ConnCallback connCallback) {
        mConnCallback = connCallback;
        Intent intent = new Intent("sunmi.intent.action.PAY_HARDWARE");
        intent.setPackage("com.sunmi.pay.hardware_v3");
        appContext = context.getApplicationContext();
        PackageManager pkgManager = appContext.getPackageManager();
        List<ResolveInfo> infos = pkgManager.queryIntentServices(intent, 0);
        if (infos != null && !infos.isEmpty()) {
            appContext.startService(intent);
            isBind = appContext.bindService(intent, mServiceConnection, Context.BIND_NOT_FOREGROUND);
        } else {
            Log.e(TAG, "bind PayHardwareService failed: service not found");
            Toast.makeText(context, "bind PayHardwareService failed: service not found", Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * 绑定支付SDK
     *
     * @param context  Context对象
     * @param callback 绑定操作回调对象
     * @return 绑定Service是否成功，true-成功，false-失败
     */
    public boolean initPaySDK(Context context, ConnectCallback callback) {
        isBind = false;
        mConnCallbackV2 = callback;
        Intent intent = new Intent("sunmi.intent.action.PAY_HARDWARE");
        intent.setPackage("com.sunmi.pay.hardware_v3");
        appContext = context.getApplicationContext();
        PackageManager pkgManager = appContext.getPackageManager();
        List<ResolveInfo> infos = pkgManager.queryIntentServices(intent, 0);
        if (infos != null && !infos.isEmpty()) {
            appContext.startService(intent);
            isBind = appContext.bindService(intent, mServiceConnection, Context.BIND_NOT_FOREGROUND);
        } else {
            Log.e(TAG, "bind PayHardwareService failed: service not found");
            Toast.makeText(context, "bind PayHardwareService failed: service not found", Toast.LENGTH_SHORT).show();
        }
        return isBind;
    }

    /**
     * 解绑支付SDK
     *
     * @param context Context对象
     */
    @Deprecated
    public void unbindPayService(Context context) {
        if (mServiceConnection != null && isBind) {
            context.getApplicationContext().unbindService(mServiceConnection);
            isBind = false;
        }
    }

    /**
     * 解绑支付SDK
     */
    public void destroyPaySDK() {
        if (mServiceConnection != null && isBind) {
            appContext.unbindService(mServiceConnection);
            isBind = false;
        }
    }

    /** 绑定支付SDK Service回调对象 */
    private ServiceConnection mServiceConnection = new ServiceConnection() {
        @Override
        public void onServiceConnected(ComponentName name, IBinder service) {
            try {
                DeviceProvide provider = DeviceProvide.Stub.asInterface(service);
                if (!setBinder(provider)) {
                    return;
                }
                mBasicOpt = getBinder(provider, BasicOpt.class);
                mReadCardOpt = getBinder(provider, ReadCardOpt.class);
                mPinPadOpt = getBinder(provider, PinPadOpt.class);
                mEMVOpt = getBinder(provider, EMVOpt.class);
                mSecurityOpt = getBinder(provider, SecurityOpt.class);
                mPrinterOpt = getBinder(provider, PrinterOpt.class);
                mTaxOpt = getBinder(provider, TaxOpt.class);
                mBasicOptV2 = getBinder(provider, BasicOptV2.class);
                mReadCardOptV2 = getBinder(provider, ReadCardOptV2.class);
                mPinPadOptV2 = getBinder(provider, PinPadOptV2.class);
                mEMVOptV2 = getBinder(provider, EMVOptV2.class);
                mSecurityOptV2 = getBinder(provider, SecurityOptV2.class);
                mPrinterOptV2 = getBinder(provider, PrinterOptV2.class);
                mTaxOptV2 = getBinder(provider, TaxOptV2.class);
                mETCOptV2 = getBinder(provider, ETCOptV2.class);
                if (mConnCallback != null) {
                    mConnCallback.onServiceConnected();
                }
                if (mConnCallbackV2 != null) {
                    mConnCallbackV2.onConnectPaySDK();
                }
            } catch (Exception e) {
                e.printStackTrace();
                Log.e(TAG, "bind service exception:" + e);
            }
        }

        @Override
        public void onServiceDisconnected(ComponentName name) {
            if (mConnCallback != null) {
                mConnCallback.onServiceDisconnected();
            }
            if (mConnCallbackV2 != null) {
                mConnCallbackV2.onDisconnectPaySDK();
            }
        }

        /** 设置Binder，Service端根据此Binder监测client端进程是否死掉 */
        private boolean setBinder(DeviceProvide provider) {
            try {
                return provider.setBinder(new Binder()) >= 0;
            } catch (Exception e) {
                e.printStackTrace();
            }
            return false;
        }

        @SuppressWarnings("unchecked")
        private <T> T getBinder(DeviceProvide provider, Class<T> clazz) {
            IInterface binder = null;
            try {
                if (clazz == BasicOpt.class) {
                    binder = provider.getBasicOpt();
                } else if (clazz == ReadCardOpt.class) {
                    binder = provider.getReadCardOpt();
                } else if (clazz == PinPadOpt.class) {
                    binder = provider.getPinPadOpt();
                } else if (clazz == EMVOpt.class) {
                    binder = provider.getEMVOpt();
                } else if (clazz == SecurityOpt.class) {
                    binder = provider.getSecurityOpt();
                } else if (clazz == PrinterOpt.class) {
                    binder = provider.getPrinterOpt();
                } else if (clazz == TaxOpt.class) {
                    binder = provider.getTaxOpt();
                } else if (clazz == BasicOptV2.class) {
                    binder = provider.getBasicOptV2();
                } else if (clazz == ReadCardOptV2.class) {
                    binder = provider.getReadCardOptV2();
                } else if (clazz == PinPadOptV2.class) {
                    binder = provider.getPinPadOptV2();
                } else if (clazz == EMVOptV2.class) {
                    binder = provider.getEMVOptV2();
                } else if (clazz == SecurityOptV2.class) {
                    binder = provider.getSecurityOptV2();
                } else if (clazz == PrinterOptV2.class) {
                    binder = provider.getPrinterOptV2();
                } else if (clazz == TaxOptV2.class) {
                    binder = provider.getTaxOptV2();
                } else if (clazz == ETCOptV2.class) {
                    binder = provider.getETCOptV2();
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
            return (T) binder;
        }
    };

    /**
     * 屏幕独占 禁用底部导航栏和SystemUI下拉框、保持屏幕高亮，不锁屏、禁用音量键
     */
    public static void screenMonopoly(Window window) {
        UIUtils.screenMonopoly(window);
    }

    /**
     * dialog弹出时调用此函数可实现屏幕独占
     * 禁用底部导航栏和SystemUI下拉框、保持屏幕高亮，不锁屏、禁用音量键
     */
    public static void screenMonopoly(Dialog dialog) {
        UIUtils.screenMonopoly(dialog);
    }

    /** 支付SDK绑定结果回调 */
    @Deprecated
    public interface ConnCallback {
        /** 连接成功 */
        void onServiceConnected();

        /** 连接断开 */
        void onServiceDisconnected();
    }

    /** 连接支付SDK回调接口 */
    public interface ConnectCallback {
        /** 连接成功 */
        void onConnectPaySDK();

        /** 连接断开 */
        void onDisconnectPaySDK();
    }
}
